// Copyright 2020 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

'use strict';
// sample-metadata:
//  title: Metadata
//  description: List the types of sensitive information the DLP API supports
//  usage: node metadata.js my-project langaugeCode filter

function main(projectId, languageCode, filter) {
  // [START dlp_list_info_types]
  // Imports the Google Cloud Data Loss Prevention library
  const DLP = require('@google-cloud/dlp');

  // Instantiates a client
  const dlp = new DLP.DlpServiceClient();

  // The project ID to run the API call under
  // const projectId = 'my-project';

  // The BCP-47 language code to use, e.g. 'en-US'
  // const languageCode = 'en-US';

  // The filter to use
  // const filter = 'supported_by=INSPECT'

  async function listInfoTypes() {
    const [response] = await dlp.listInfoTypes({
      languageCode: languageCode,
      filter: filter,
    });
    const infoTypes = response.infoTypes;
    console.log('Info types:');
    infoTypes.forEach(infoType => {
      console.log(`\t${infoType.name} (${infoType.displayName})`);
    });
  }

  listInfoTypes();
  // [END dlp_list_info_types]
}

module.exports.main = main;

main(...process.argv.slice(2));
process.on('unhandledRejection', err => {
  console.error(err.message);
  process.exitCode = 1;
});
